lpadmin(8)

lpadmin - configure cups printers and classes

Showing IRIX 6.5.30 (default release). Added in IRIX 6.5.30.

NAME
     lpadmin - configure cups printers and classes

SYNOPSIS
     lpadmin [ -E ] [ -h server ] -d destination
     lpadmin [ -E ] [ -h server ] -p printer option(s)
     lpadmin [ -E ] [ -h server ] -x destination

DESCRIPTION
     lpadmin  configures  printer and class queues provided by CUPS. It can also
     be used to set the server default printer or class.

     When specified before the -d, -p, or -x options, the -E option  forces  en-
     cryption when connecting to the server.

     The first form of the command sets the default printer or class to destina-
     tion.   Subsequent  print  jobs  submitted via the lp(1) or lpr(1) commands
     will use this destination unless the  user  specifies  otherwise  with  the
     lpoptions(1) command.

     The  second  form  of  the command configures the named printer.  The addi-
     tional options are described below.

     The third form of the command deletes the  printer  or  class  destination.
     Any  jobs  that are pending for the destination will be removed and any job
     that is currently printed will be aborted.

CONFIGURATION OPTIONS
     The following options are recognized when configuring a printer queue:

     -c class
          Adds the named printer to class.  If class does not exist it  is  cre-
          ated automatically.

     -i interface
          Sets  a  System V style interface script for the printer.  This option
          cannot be specified with the -P option (PPD file) and is intended  for
          providing support for legacy printer drivers.

     -m model
          Sets  a  standard System V interface script or PPD file from the model
          directory.

     -o name=value
          Sets a PPD or server option for the printer. PPD options can be listed
          using the -l option with the lpoptions(1) command.

     -o job-k-limit=value
          Sets the kilobyte limit for per-user quotas. The value is  an  integer
          number of kilobytes; one kilobyte is 1024 bytes.

     -o job-page-limit=value
          Sets the page limit for per-user quotas. The value is the integer num-
          ber  of  pages  that can be printed; double-sided pages are counted as
          two pages.

     -o job-quota-period=value
          Sets the accounting period for per-user quotas. The value is an  inte-
          ger number of seconds; 86,400 seconds are in one day.

     -o protocol=name
          Sets  the  binary  communications protocol to use when printing, None,
          BCP, or TBCP. The default protocol is None.

     -r class
          Removes the named printer from class.  If the resulting class  becomes
          empty it is removed.

     -u allow:user,user,@group
          -u deny:user,user,@group -u allow:all -u deny:none
          Sets  user-level  access control on a printer. Names starting with "@"
          are interpreted as UNIX groups. The latter two forms  turn  user-level
          access control off.

     -v device-uri
          Sets  the device-uri attribute of the printer queue.  If device-uri is
          a filename it is automatically converted to the form file:/file/name.

     -D info
          Provides a textual description of the printer.

     -E
          Enables the printer and accepts jobs; this is the same as running  the
          accept(8) and enable(8) programs on the printer.

     -L location
          Provides a textual location of the printer.

     -P ppd-file
          Specifies  a  PostScript  Printer  Description  file  to  use with the
          printer. If specified, this option overrides the -i option  (interface
          script).

COMPATIBILITY
     Unlike  the  System V printing system, CUPS allows printer names to contain
     any printable character except SPACE and TAB. Also, printer and class names
     are not case-sensitive. Finally, the CUPS version of lpadmin  may  ask  the
     user for an access password depending on the printing system configuration.
     This differs from the System V version which requires the root user to exe-
     cute this command.

LIMITATIONS
     The CUPS version of lpadmin does not support all of the System V or Solaris
     printing system configuration options.

SEE ALSO
     accept(8),  cancel(1),  disable(8), enable(8), lp(1), lpstat(1), reject(8),
     CUPS  Software   Administrators   Manual,   http://localhost:631/documenta-
     tion.html

COPYRIGHT
     Copyright 1993-2005 by Easy Software Products, All Rights Reserved.